Repr

Struct Repr 

#[repr(transparent)]
pub(super) struct Repr(NonNull<()>, PhantomData<ErrorData<CustomOwner>>);
🔬This is a nightly-only experimental API. (core_io #154046)
The internal representation.

See the module docs for more, this is just a way to hack in a check that we indeed are not unwind-safe.

fn is_unwind_safe<T: core::panic::UnwindSafe>() {}
is_unwind_safe::<std::io::Error>();

Tuple Fields

0: NonNull<()>
🔬This is a nightly-only experimental API. (core_io #154046)
1: PhantomData<ErrorData<CustomOwner>>
🔬This is a nightly-only experimental API. (core_io #154046)

Implementations

Source

impl Repr

pub(super) fn new_custom(b: CustomOwner) -> Self

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) fn new_os(code: RawOsError) -> Self

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) fn new_simple(kind: ErrorKind) -> Self

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) const fn new_simple_message(m: &'static SimpleMessage) -> Self

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) fn data(&self) -> ErrorData<&Custom>

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) fn data_mut(&mut self) -> ErrorData<&mut Custom>

🔬This is a nightly-only experimental API. (core_io #154046)
pub(super) fn into_data(self) -> ErrorData<CustomOwner>

🔬This is a nightly-only experimental API. (core_io #154046)